/****************************************************************************
** Meta object code from reading C++ file 'kmidimon.h'
**
** Created by: The Qt Meta Object Compiler version 68 (Qt 6.8.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmidimon-RELEASE_1_4_1/src/kmidimon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmidimon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 68
#error "This file was generated using the moc from 6.8.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KMidimonE_t {};
} // unnamed namespace


#ifdef QT_MOC_HAS_STRINGDATA
static constexpr auto qt_meta_stringdata_ZN8KMidimonE = QtMocHelpers::stringData(
    "KMidimon",
    "fileNew",
    "",
    "fileOpen",
    "fileSave",
    "preferences",
    "record",
    "stop",
    "play",
    "pause",
    "rewind",
    "forward",
    "connectAll",
    "addTrack",
    "deleteCurrentTrack",
    "changeCurrentTrack",
    "muteCurrentTrack",
    "deleteTrack",
    "tabIndex",
    "changeTrack",
    "muteTrack",
    "songFinished",
    "open",
    "fileName",
    "tempoReset",
    "tempoSlider",
    "value",
    "about",
    "help",
    "slotOpenWebSite",
    "disconnectAll",
    "configConnections",
    "updateState",
    "PlayerState",
    "newState",
    "setColumnStatus",
    "colNum",
    "status",
    "toggleColumn",
    "modelRowsInserted",
    "QModelIndex",
    "parent",
    "start",
    "end",
    "resizeAllColumns",
    "tabIndexChanged",
    "index",
    "reorderTabs",
    "fromIndex",
    "toIndex",
    "slotTicks",
    "row",
    "slotCurrentChanged",
    "curr",
    "prev",
    "updateView",
    "songFileInfo",
    "slotSwitchLanguage",
    "QAction*",
    "action",
    "closeEvent",
    "QCloseEvent*",
    "event",
    "contextMenuEvent",
    "QContextMenuEvent*",
    "ev",
    "dropEvent",
    "QDropEvent*",
    "dragEnterEvent",
    "QDragEnterEvent*",
    "updateRecentFileActions",
    "openRecentFile",
    "InvalidState",
    "RecordingState",
    "PlayingState",
    "PausedState",
    "StoppedState"
);
#else  // !QT_MOC_HAS_STRINGDATA
#error "qtmochelpers.h not found or too old."
#endif // !QT_MOC_HAS_STRINGDATA

Q_CONSTINIT static const uint qt_meta_data_ZN8KMidimonE[] = {

 // content:
      12,       // revision
       0,       // classname
       0,    0, // classinfo
      45,   14, // methods
       0,    0, // properties
       1,  375, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags, initial metatype offsets
       1,    0,  284,    2, 0x0a,    2 /* Public */,
       3,    0,  285,    2, 0x0a,    3 /* Public */,
       4,    0,  286,    2, 0x0a,    4 /* Public */,
       5,    0,  287,    2, 0x0a,    5 /* Public */,
       6,    0,  288,    2, 0x0a,    6 /* Public */,
       7,    0,  289,    2, 0x0a,    7 /* Public */,
       8,    0,  290,    2, 0x0a,    8 /* Public */,
       9,    0,  291,    2, 0x0a,    9 /* Public */,
      10,    0,  292,    2, 0x0a,   10 /* Public */,
      11,    0,  293,    2, 0x0a,   11 /* Public */,
      12,    0,  294,    2, 0x0a,   12 /* Public */,
      13,    0,  295,    2, 0x0a,   13 /* Public */,
      14,    0,  296,    2, 0x0a,   14 /* Public */,
      15,    0,  297,    2, 0x0a,   15 /* Public */,
      16,    0,  298,    2, 0x0a,   16 /* Public */,
      17,    1,  299,    2, 0x0a,   17 /* Public */,
      19,    1,  302,    2, 0x0a,   19 /* Public */,
      20,    1,  305,    2, 0x0a,   21 /* Public */,
      21,    0,  308,    2, 0x0a,   23 /* Public */,
      22,    1,  309,    2, 0x0a,   24 /* Public */,
      24,    0,  312,    2, 0x0a,   26 /* Public */,
      25,    1,  313,    2, 0x0a,   27 /* Public */,
      27,    0,  316,    2, 0x0a,   29 /* Public */,
      28,    0,  317,    2, 0x0a,   30 /* Public */,
      29,    0,  318,    2, 0x0a,   31 /* Public */,
      30,    0,  319,    2, 0x0a,   32 /* Public */,
      31,    0,  320,    2, 0x0a,   33 /* Public */,
      32,    1,  321,    2, 0x0a,   34 /* Public */,
      35,    2,  324,    2, 0x0a,   36 /* Public */,
      38,    1,  329,    2, 0x0a,   39 /* Public */,
      39,    3,  332,    2, 0x0a,   41 /* Public */,
      44,    0,  339,    2, 0x0a,   45 /* Public */,
      45,    1,  340,    2, 0x0a,   46 /* Public */,
      47,    2,  343,    2, 0x0a,   48 /* Public */,
      50,    1,  348,    2, 0x0a,   51 /* Public */,
      52,    2,  351,    2, 0x0a,   53 /* Public */,
      55,    0,  356,    2, 0x0a,   56 /* Public */,
      56,    0,  357,    2, 0x0a,   57 /* Public */,
      57,    1,  358,    2, 0x0a,   58 /* Public */,
      60,    1,  361,    2, 0x0a,   60 /* Public */,
      63,    1,  364,    2, 0x0a,   62 /* Public */,
      66,    1,  367,    2, 0x0a,   64 /* Public */,
      68,    1,  370,    2, 0x0a,   66 /* Public */,
      70,    0,  373,    2, 0x0a,   68 /* Public */,
      71,    0,  374,    2, 0x0a,   69 /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void, QMetaType::Int,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   36,   37,
    QMetaType::Void, QMetaType::Int,   36,
    QMetaType::Void, 0x80000000 | 40, QMetaType::Int, QMetaType::Int,   41,   42,   43,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   46,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   48,   49,
    QMetaType::Void, QMetaType::Int,   51,
    QMetaType::Void, 0x80000000 | 40, 0x80000000 | 40,   53,   54,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 58,   59,
    QMetaType::Void, 0x80000000 | 61,   62,
    QMetaType::Void, 0x80000000 | 64,   65,
    QMetaType::Void, 0x80000000 | 67,   62,
    QMetaType::Void, 0x80000000 | 69,   62,
    QMetaType::Void,
    QMetaType::Void,

 // enums: name, alias, flags, count, data
      33,   33, 0x0,    5,  380,

 // enum data: key, value
      72, uint(KMidimon::InvalidState),
      73, uint(KMidimon::RecordingState),
      74, uint(KMidimon::PlayingState),
      75, uint(KMidimon::PausedState),
      76, uint(KMidimon::StoppedState),

       0        // eod
};

Q_CONSTINIT const QMetaObject KMidimon::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_ZN8KMidimonE.offsetsAndSizes,
    qt_meta_data_ZN8KMidimonE,
    qt_static_metacall,
    nullptr,
    qt_incomplete_metaTypeArray<qt_meta_tag_ZN8KMidimonE_t,
        // enum 'PlayerState'
        QtPrivate::TypeAndForceComplete<KMidimon::PlayerState, std::true_type>,
        // Q_OBJECT / Q_GADGET
        QtPrivate::TypeAndForceComplete<KMidimon, std::true_type>,
        // method 'fileNew'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'fileOpen'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'fileSave'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'preferences'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'record'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'stop'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'play'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'pause'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'rewind'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'forward'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'connectAll'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'addTrack'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'deleteCurrentTrack'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'changeCurrentTrack'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'muteCurrentTrack'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'deleteTrack'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'changeTrack'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'muteTrack'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'songFinished'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'open'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QString &, std::false_type>,
        // method 'tempoReset'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'tempoSlider'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'about'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'help'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'slotOpenWebSite'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'disconnectAll'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'configConnections'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'updateState'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<PlayerState, std::false_type>,
        // method 'setColumnStatus'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<bool, std::false_type>,
        // method 'toggleColumn'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'modelRowsInserted'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'resizeAllColumns'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'tabIndexChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'reorderTabs'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'slotTicks'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<int, std::false_type>,
        // method 'slotCurrentChanged'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        QtPrivate::TypeAndForceComplete<const QModelIndex &, std::false_type>,
        // method 'updateView'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'songFileInfo'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'slotSwitchLanguage'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<QAction *, std::false_type>,
        // method 'closeEvent'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<QCloseEvent *, std::false_type>,
        // method 'contextMenuEvent'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<QContextMenuEvent *, std::false_type>,
        // method 'dropEvent'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<QDropEvent *, std::false_type>,
        // method 'dragEnterEvent'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        QtPrivate::TypeAndForceComplete<QDragEnterEvent *, std::false_type>,
        // method 'updateRecentFileActions'
        QtPrivate::TypeAndForceComplete<void, std::false_type>,
        // method 'openRecentFile'
        QtPrivate::TypeAndForceComplete<void, std::false_type>
    >,
    nullptr
} };

void KMidimon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMidimon *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileNew(); break;
        case 1: _t->fileOpen(); break;
        case 2: _t->fileSave(); break;
        case 3: _t->preferences(); break;
        case 4: _t->record(); break;
        case 5: _t->stop(); break;
        case 6: _t->play(); break;
        case 7: _t->pause(); break;
        case 8: _t->rewind(); break;
        case 9: _t->forward(); break;
        case 10: _t->connectAll(); break;
        case 11: _t->addTrack(); break;
        case 12: _t->deleteCurrentTrack(); break;
        case 13: _t->changeCurrentTrack(); break;
        case 14: _t->muteCurrentTrack(); break;
        case 15: _t->deleteTrack((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->changeTrack((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->muteTrack((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->songFinished(); break;
        case 19: _t->open((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->tempoReset(); break;
        case 21: _t->tempoSlider((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->about(); break;
        case 23: _t->help(); break;
        case 24: _t->slotOpenWebSite(); break;
        case 25: _t->disconnectAll(); break;
        case 26: _t->configConnections(); break;
        case 27: _t->updateState((*reinterpret_cast< std::add_pointer_t<PlayerState>>(_a[1]))); break;
        case 28: _t->setColumnStatus((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<bool>>(_a[2]))); break;
        case 29: _t->toggleColumn((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->modelRowsInserted((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[3]))); break;
        case 31: _t->resizeAllColumns(); break;
        case 32: _t->tabIndexChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->reorderTabs((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<int>>(_a[2]))); break;
        case 34: _t->slotTicks((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->slotCurrentChanged((*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 36: _t->updateView(); break;
        case 37: _t->songFileInfo(); break;
        case 38: _t->slotSwitchLanguage((*reinterpret_cast< std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 39: _t->closeEvent((*reinterpret_cast< std::add_pointer_t<QCloseEvent*>>(_a[1]))); break;
        case 40: _t->contextMenuEvent((*reinterpret_cast< std::add_pointer_t<QContextMenuEvent*>>(_a[1]))); break;
        case 41: _t->dropEvent((*reinterpret_cast< std::add_pointer_t<QDropEvent*>>(_a[1]))); break;
        case 42: _t->dragEnterEvent((*reinterpret_cast< std::add_pointer_t<QDragEnterEvent*>>(_a[1]))); break;
        case 43: _t->updateRecentFileActions(); break;
        case 44: _t->openRecentFile(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KMidimon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMidimon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ZN8KMidimonE.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int KMidimon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}
QT_WARNING_POP
