/***************************************************************************
 *   Drumstick MIDI monitor based on the ALSA Sequencer                    *
 *   Copyright (C) 2005-2024 Pedro Lopez-Cabanillas                        *
 *   plcl@users.sourceforge.net                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
 ***************************************************************************/

#ifndef CONNECTDLG_H
#define CONNECTDLG_H

#include <QDialog>

class QGroupBox;
class QComboBox;
class QCheckBox;

 class ConnectDlg : public QDialog
{
    Q_OBJECT

 public:
    ConnectDlg( QWidget *parent,
                const QStringList& inputs,
                const QStringList& subs,
                const QStringList& outputs,
                const QString& out);

    QStringList getSelectedInputs() const;
    QString getSelectedOutput() const;

    void setThruEnabled(bool enable);
    bool isThruEnabled() const;

private:
    QGroupBox* m_group;
    QComboBox* m_output;
    QCheckBox* m_thru;
};

#endif
